==> ejc-proequipmentcorp-impl-3.0.0-20221103.091916-120-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseApply/service/impl/PurchaseApplyBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.purchaseApply.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.proequipmentcorppur.purchase.bean.ChangePurchaseContractDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchase.bean.PurchaseContractDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchase.service.IChangePurchaseContractDetailedService;
import com.ejianc.business.proequipmentcorppur.purchase.service.IPurchaseContractDetailedService;
import com.ejianc.business.proequipmentcorppur.purchaseApply.bean.PurchaseApplyDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchaseApply.bean.PurchaseApplyEntity;
import com.ejianc.business.proequipmentcorppur.purchaseApply.service.IPurchaseApplyService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service("purchaseApply")
public class PurchaseApplyBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IPurchaseApplyService service;
	@Autowired
	private IPurchaseContractDetailedService detailedService;
	@Autowired
	private IChangePurchaseContractDetailedService changeDetailedService;
	@Autowired
	private IBillTypeApi billTypeApi;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		PurchaseApplyEntity planEntity = service.selectById(billId);

		List<PurchaseApplyDetailedEntity> subEntityList = planEntity.getDetailList();
		if(CollectionUtils.isNotEmpty(subEntityList)){
			List<Long> batchIds = subEntityList.stream().map(PurchaseApplyDetailedEntity::getId).collect(Collectors.toList());
			QueryWrapper<PurchaseContractDetailedEntity> queryDetaile = new QueryWrapper<PurchaseContractDetailedEntity>();
			queryDetaile.in("source_id", batchIds);
			queryDetaile.eq("dr", 0);
			List<PurchaseContractDetailedEntity> equipmentList = detailedService.list(queryDetaile);

			QueryWrapper<ChangePurchaseContractDetailedEntity> queryChangeDetaile = new QueryWrapper<ChangePurchaseContractDetailedEntity>();
			queryChangeDetaile.in("source_id", batchIds);
			queryChangeDetaile.eq("dr", 0);
			List<ChangePurchaseContractDetailedEntity> changeEquipmentList = changeDetailedService.list(queryChangeDetaile);

			if(CollectionUtils.isNotEmpty(equipmentList) || CollectionUtils.isNotEmpty(changeEquipmentList)){
				return CommonResponse.error("清单被下游单据引用，不允许回退!");
			}
			// 如果是待采购，则不判断是否引用
//			if (PurchasePlanEnum.PLAN_STATE_WAIT.getPlanState().equals(planEntity.getPlanState())) {
//				return CommonResponse.success();
//			}
			CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
			if (!resp.isSuccess()) {
				return CommonResponse.error("单据被引用不能撤回！");
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-proequipmentcorp-impl-3.0.0-20250923.034303-514-sources.jar: com/ejianc/business/proequipmentcorppur/purchaseApply/service/impl/PurchaseApplyBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.purchaseApply.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.proequipmentcorppur.purchase.bean.ChangePurchaseContractDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchase.bean.PurchaseContractDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchase.service.IChangePurchaseContractDetailedService;
import com.ejianc.business.proequipmentcorppur.purchase.service.IPurchaseContractDetailedService;
import com.ejianc.business.proequipmentcorppur.purchaseApply.bean.PurchaseApplyDetailedEntity;
import com.ejianc.business.proequipmentcorppur.purchaseApply.bean.PurchaseApplyEntity;
import com.ejianc.business.proequipmentcorppur.purchaseApply.service.IPurchaseApplyService;
import com.ejianc.business.proequipmentcorppur.purchaseApply.vo.PurchaseApplyVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service("purchaseApply")
public class PurchaseApplyBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IPurchaseApplyService service;
	@Autowired
	private IPurchaseContractDetailedService detailedService;
	@Autowired
	private IChangePurchaseContractDetailedService changeDetailedService;
	@Autowired
	private IBillTypeApi billTypeApi;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		PurchaseApplyEntity planEntity = service.selectById(billId);

		List<PurchaseApplyDetailedEntity> subEntityList = planEntity.getDetailList();
		if(CollectionUtils.isNotEmpty(subEntityList)){
			List<Long> batchIds = subEntityList.stream().map(PurchaseApplyDetailedEntity::getId).collect(Collectors.toList());
			QueryWrapper<PurchaseContractDetailedEntity> queryDetaile = new QueryWrapper<PurchaseContractDetailedEntity>();
			queryDetaile.in("source_id", batchIds);
			queryDetaile.eq("dr", 0);
			List<PurchaseContractDetailedEntity> equipmentList = detailedService.list(queryDetaile);

			QueryWrapper<ChangePurchaseContractDetailedEntity> queryChangeDetaile = new QueryWrapper<ChangePurchaseContractDetailedEntity>();
			queryChangeDetaile.in("source_id", batchIds);
			queryChangeDetaile.eq("dr", 0);
			List<ChangePurchaseContractDetailedEntity> changeEquipmentList = changeDetailedService.list(queryChangeDetaile);

			if(CollectionUtils.isNotEmpty(equipmentList) || CollectionUtils.isNotEmpty(changeEquipmentList)){
				return CommonResponse.error("清单被下游单据引用，不允许回退!");
			}
			// 如果是待采购，则不判断是否引用
//			if (PurchasePlanEnum.PLAN_STATE_WAIT.getPlanState().equals(planEntity.getPlanState())) {
//				return CommonResponse.success();
//			}
			CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
			if (!resp.isSuccess()) {
				return CommonResponse.error("单据被引用不能撤回！");
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	@Override
	public CommonResponse<JSONObject> getBpmVariable(Long billId, String billTypeCode) {
		PurchaseApplyEntity e = service.selectById(billId);
		ParamsCheckVO paramsCheckVO = service.checkParams(BeanMapper.map(e, PurchaseApplyVO.class));
		JSONObject object = new JSONObject();
		if(null != paramsCheckVO && paramsCheckVO.getDataSource().size() > 0){
			object.put("priceFlag","是");//是单价异常
		}else{
			object.put("priceFlag","否");//否 单价异常
		}
		return CommonResponse.success(object);
	}
}
